/*
 * tunable.h -- values that a site might want to change
 *
 * For license terms, see the file COPYING in this directory.
 */

/* umask to use when daemon creates files */
#define	DEF_UMASK		022

/* default timeout period in seconds if server connection dies */
#define	CLIENT_TIMEOUT		300

/* default skipped message warning interval in seconds */
#define WARNING_INTERVAL	3600

